@@ -5,13 +5,11 @@
 #' done automatically and can be done manually by running
 #' \code{install_genderdata_package()}.
 #'
-#' @name gender
 #' @docType package
+#' @name gender-package
 #' @title Gender: predict gender by name from historical data
 #' @author \email{lincoln@@lincolnmullen.com}
-#' @keywords gender
-#' @import devtools
 #' @import dplyr
-#' @import jsonlite
-#' @import httr
-"gender"
+#' @importFrom utils data
+#' @importFrom utils menu
+NULL
