@@ -1,6 +1,6 @@
 library(testthat)
-if("genderdata" %in% installed.packages()) {
-  test_check("gender")
+if (requireNamespace("genderdata", quietly = TRUE)) {
+  test_check("gender", filter = "demo")
 } else {
   test_check("gender", filter = "demo")
 }
